@@ -3,7 +3,7 @@ import yaml
 
 from ..cheks import check_diff_responses
 from ..exceptions import get_grouped_exception
-from ..play import Replayed, reed_conf, replay
+from ..play import Replayed, replay
 
 
 def bold(message):
@@ -38,6 +38,5 @@ def run(cassette_path, status=None, uri=None, diff=False, config=None):
         raise exception_cls(Replayed.errors)
     if diff:
         with open(config) as fd2:
-            conf = yaml.load(fd2, Loader=yaml.SafeLoader)
-        Replayed.config = reed_conf(conf)
+            Replayed.config  = yaml.load(fd2, Loader=yaml.SafeLoader)
         check_diff_responses()
